aboutsummaryrefslogtreecommitdiffstats
path: root/scripts/windows/appveyor/install.ps1
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/windows/appveyor/install.ps1')
-rw-r--r--scripts/windows/appveyor/install.ps116
1 files changed, 8 insertions, 8 deletions
diff --git a/scripts/windows/appveyor/install.ps1 b/scripts/windows/appveyor/install.ps1
index bf780fa19..d377bfe21 100644
--- a/scripts/windows/appveyor/install.ps1
+++ b/scripts/windows/appveyor/install.ps1
@@ -1,13 +1,13 @@
-Write-Host "Installing dependencies ..." -Foreground Yellow
-Write-Host "----------------------------------------" -Foreground Yellow
-Write-Host "Installing MinGW64 packages ..." -Foreground Yellow
+Write-Host "Installing dependencies ..." -ForegroundColor Yellow
+Write-Host "----------------------------------------" -ForegroundColor Yellow
+Write-Host "Installing MinGW64 packages ..." -ForegroundColor Yellow
C:\msys64\usr\bin\pacman -V
# list installed packages and versions
# C:\msys64\usr\bin\pacman -Q
if ($env:BUILD_MINGW -eq "mingw32")
-{ Write-Host "Installing MinGW32 packages ..." -Foreground Yellow
+{ Write-Host "Installing MinGW32 packages ..." -ForegroundColor Yellow
if ($env:BUILD_BACKEND -eq "mcode")
{
}
@@ -16,7 +16,7 @@ if ($env:BUILD_MINGW -eq "mingw32")
}
}
elseif ($env:BUILD_MINGW -eq "mingw64")
-{ Write-Host "Installing MinGW64 packages ..." -Foreground Yellow
+{ Write-Host "Installing MinGW64 packages ..." -ForegroundColor Yellow
if ($env:BUILD_BACKEND -eq "mcode")
{
}
@@ -25,15 +25,15 @@ elseif ($env:BUILD_MINGW -eq "mingw64")
}
}
-Write-Host "Installing NuGet as PackageProvider ..." -Foreground Yellow
+Write-Host "Installing NuGet as PackageProvider ..." -ForegroundColor Yellow
Install-PackageProvider NuGet -Force
Import-PackageProvider NuGet -Force
Set-PSRepository -Name PSGallery -InstallationPolicy Trusted
-Write-Host "Installing PowerShell modules ..." -Foreground Yellow
+Write-Host "Installing PowerShell modules ..." -ForegroundColor Yellow
Install-Module Pscx -AllowClobber
#Write-Host "Check all Write-* CmdLets ..." -Foreground Yellow
#Get-Command -Verb Write | Format-Table
exit $LastExitCode
@@ -25,15 +25,15 @@ elseif ($env:BUILD_MINGW -eq "mingw64")
Install-Module Pscx -AllowClobber
-#Write-Host "Check all Write-* CmdLets ..." -Foreground Yellow
+#Write-Host "Check all Write-* CmdLets ..." -ForegroundColor Yellow
#Get-Command -Verb Write | Format-Table
exit $LastExitCode